@@ -9,9 +9,6 @@ from xclim.core.units import units, units2pint
 
 from .state import BasinStateVariables, HRUStateVariables
 
-# Can be removed when xclim is pinned above 0.14
-units.define("deg_C = degC")
-
 """
 Raven configuration
 -------------------
@@ -233,17 +230,18 @@ class RavenNcData(RV):
     }
 
     _var_runits = {
-        "tasmin": "deg_C",
-        "tasmax": "deg_C",
-        "tas": "deg_C",
+        "tasmin": "degC",
+        "tasmax": "degC",
+        "tas": "degC",
         "pr": "mm/d",
         "rainfall": "mm/d",
         "prsn": "mm/d",
         "evspsbl": "mm/d",
-        "water_volume_transport_in_river_channel": "m3/s",
+        "water_volume_transport_in_river_channel": "m**3/s",
     }
 
     def __init__(self, **kwargs):
+        """Instantiate from attributes scrapped from the netCDF file."""
         self.var = None
         self.path = None
         self.var_name = None
@@ -490,8 +488,13 @@ class RVI(RV):
         else:
             raise ValueError("Must be datetime")
 
-        if x != dt.datetime(1, 1, 1):
+        if x == dt.datetime(1, 1, 1):
+            return
+
+        if self._duration is None:
             self._update_duration()
+        else:
+            self._update_end_date()
 
     @property
     def end_date(self):
@@ -665,16 +668,10 @@ class RVC(RV):
         path : string
           `solution.rvc` content.
         """
-
-        data = parse_solution(rvc)
-        for index, params in data["HRUStateVariableTable"]["data"].items():
-            self._hru_state[index] = HRUStateVariables(*params)
-
-        for index, raw in data["BasinStateVariables"]["BasinIndex"].items():
-            params = {k.lower(): v for (k, v) in raw.items()}
-            self._basin_state[index] = BasinStateVariables(**params)
-
-        return
+        objs = parse_solution(rvc)
+        hru, basin = get_states(objs)
+        self._hru_state.update(hru)
+        self._basin_state.update(basin)
 
     @property
     def hru_state(self):
@@ -860,6 +857,33 @@ def guess_linear_transform(actual, expected):
     # TODO : For precip we also need the frequency to sum over one day.
 
 
+def get_states(solution, hru_index=None, basin_index=None):
+    """Return state variables.
+
+    Parameters
+    ----------
+    solution : dict
+      `solution.rvc` parsed content.
+    """
+    hru_state = {}
+    basin_state = {}
+
+    for index, params in solution["HRUStateVariableTable"]["data"].items():
+        hru_state[index] = HRUStateVariables(*params)
+
+    for index, raw in solution["BasinStateVariables"]["BasinIndex"].items():
+        params = {k.lower(): v for (k, v) in raw.items()}
+        basin_state[index] = BasinStateVariables(**params)
+
+    if hru_index is not None:
+        hru_state = hru_state[hru_index]
+
+    if basin_index is not None:
+        basin_state = basin_state[basin_index]
+
+    return hru_state, basin_state
+
+
 def parse_solution(rvc):
     """Parse solution file and return dictionary of parameters that can then be used to reinitialize the model.
 
