@@ -13,10 +13,11 @@ import xarray as xr
 from ravenpy.models import get_model
 
 from . import coords
-from .testdata import get_local_testdata
 
 LOGGER = logging.getLogger("PYWPS")
 
+regionalisation_data_dir = Path(__file__).parent.parent / "data" / "regionalisation"
+
 
 def regionalize(
     method,
@@ -172,7 +173,7 @@ def read_gauged_properties(properties):
     pd.DataFrame
       Catchment properties keyed by catchment ID.
     """
-    f = get_local_testdata("regionalisation_data/gauged_catchment_properties.csv")
+    f = regionalisation_data_dir / "gauged_catchment_properties.csv"
     proptable = pd.read_csv(f, index_col="ID")
 
     return proptable[properties]
@@ -188,7 +189,7 @@ def read_gauged_params(model):
     pd.DataFrame
       Model parameters keyed by catchment ID.
     """
-    f = get_local_testdata(f"regionalisation_data/{model}_parameters.csv")
+    f = regionalisation_data_dir / f"{model}_parameters.csv"
     params = pd.read_csv(f, index_col="ID")
 
     return params["NASH"], params.iloc[:, 1:]
