@@ -1,10 +1,6 @@
 import datetime as dt
-import tempfile
-
-from fiona.io import ZipMemoryFile
 
 from ravenpy.models import GR4JCN
-from ravenpy.utilities import forecasting
 from ravenpy.utilities.testdata import get_local_testdata
 
 """
@@ -18,9 +14,6 @@ but this is a good proof of concept.
 class TestHindcasting:
     def test_hindcasting_GEPS(self, tmpdir):
 
-        # Set the hindcasting date
-        date = dt.datetime(2018, 6, 1)
-
         # Prepare a RAVEN model run using historical data, GR4JCN in this case.
         # This is a dummy run to get initial states. In a real forecast situation,
         # this run would end on the day before the forecast, but process is the same.
@@ -42,18 +35,8 @@ class TestHindcasting:
         # Extract the final states that will be used as the next initial states
         rvc = model.outputs["solution"]
 
-        # Collect the hindcast data for the date, location and climate model.
-        # Limited to GEPS for now, for a restricted period (2017-06-01 to 2018-08-31)
-        with open(get_local_testdata("watershed_vector/LSJ_LL.zip"), "rb") as f:
-            with ZipMemoryFile(f.read()) as z:
-                region_coll = z.open("LSJ_LL.shp")
-                fcst = forecasting.get_hindcast_day(
-                    region_coll, date, climate_model="GEPS"
-                )
-
-        # write the forecast data to file
-        ts = f"{tmpdir}/fcstfile.nc"
-        fcst.to_netcdf(ts)
+        ts20 = get_local_testdata("caspar_eccc_hindcasts/geps_watershed.nc")
+        nm = 20
 
         # It is necessary to clean the model state because the input variables of the previous
         # model are not the same as the ones provided in the forecast model. therefore, if we
@@ -65,8 +48,8 @@ class TestHindcasting:
 
         # And run the model with the forecast data.
         model(
-            ts=ts,
-            nc_index=range(fcst.dims.get("member")),
+            ts=ts20,
+            nc_index=range(nm),
             start_date=dt.datetime(2018, 6, 1),
             end_date=dt.datetime(2018, 6, 10),
             area=44250.6,
@@ -85,5 +68,6 @@ class TestHindcasting:
 
         # The model now has the forecast data generated and it has 10 days of forecasts.
         assert len(model.q_sim.values) == 10
+
         # Also see if GEPS has 20 members produced.
-        assert model.q_sim.values.shape[1] == 20
+        assert model.q_sim.values.shape[1] == nm
